pub struct ClientHandle { /* private fields */ }Expand description
A handle for the client side of an upgraded WebSocket connection.
Implementations
Sourceimpl ClientHandle
impl ClientHandle
Sourcepub fn send_to_server(&self, frame: UnitFrame)
pub fn send_to_server(&self, frame: UnitFrame)
Encode frame and deliver it to the policy via on_http_request_body.
Outgoing calls triggered by the policy are resolved inline.