pub struct ServerHandle { /* private fields */ }Expand description
A handle for the server side of an upgraded WebSocket connection.
Implementations
Sourceimpl ServerHandle
impl ServerHandle
Sourcepub fn send_to_client(&self, frame: UnitFrame)
pub fn send_to_client(&self, frame: UnitFrame)
Encode frame and deliver it to the policy via on_http_response_body.
Outgoing calls triggered by the policy are resolved inline.