TraceBackend

Struct TraceBackend 

pub struct TraceBackend<B: Backend> { /* private fields */ }
A Backend that stores the incoming requests to be later retrieved by the test. Delegates the response generation to the function provided in the constructor. This classes uses the interior mutability pattern to allow the test to retrieve the requests.

Example

       let back = Rc::new(TraceBackend::new(echo_backend));

        let mut tester = UnitTestBuilder::default()
            .with_config(config)
            .with_backend(Rc::clone(&back))
            .with_entrypoint(crate::configure);

        let response = tester.request(req.clone());
        let request = back.next().unwrap();

Implementations

Source

impl<B: Backend> TraceBackend<B>

pub fn new(response: B) -> Self

Creates a new instance with the provided backend for response generation.

pub fn next(&self) -> Option<UnitHttpRequest>

Removes and returns the next request that reached the backend.