Backend

Trait Backend 

pub trait Backend {
    // Required method
    fn call(&self, req: UnitHttpRequest) -> UnitHttpResponse;
}
The interface for a backend that can be used to mock the response of an http service.

Required Methods

Implementations on Foreign Types

Source

impl<B: Backend> Backend for Rc<B>

Implementors