GrpcBackend

Trait GrpcBackend 

pub trait GrpcBackend {
    // Required method
    fn call(&self, req: UnitGrpcRequest) -> UnitGrpcResponse;
}
The interface for a backend that can be used to mock the response of a grpc service. For automatic implementation see protobuf_grpc_backend

Required Methods

Implementations on Foreign Types

Source

impl<B: GrpcBackend> GrpcBackend for Rc<B>

Implementors