pub enum StopIterationMode {
RequestsThenBody,
BodyThenRequests,
}Expand description
Controls in which order how the test framework handles forwarding call responses and body processing when using the stop_iteration mode.
This is only available when the enable_stop_iteration feature is enabled.
Variants
RequestsThenBody
Process the call responses first and then the event body.
BodyThenRequests
Process the event body first and then the call responses.