pub struct TraceBackend<B: Backend> { /* private fields */ }Expand description
A Backend that stores the incoming requests to be later retrieved by the test. Delegates the response generation to the function provided in the constructor. This classes uses the interior mutability pattern to allow the test to retrieve the requests.
Example
ⓘ
let back = Rc::new(TraceBackend::new(echo_backend));
let mut tester = UnitTestBuilder::default()
.with_config(config)
.with_backend(Rc::clone(&back))
.with_entrypoint(crate::configure);
let response = tester.request(req.clone());
let request = back.next().unwrap();Implementations
Sourceimpl<B: Backend> TraceBackend<B>
impl<B: Backend> TraceBackend<B>