pub struct UnitGrpcRequest { /* private fields */ }Expand description
Represents a gRPC request in unit tests.
This struct encapsulates the service name, method name, initial metadata, and the serialized protobuf message for gRPC calls made by policies.
Implementations
Sourceimpl UnitGrpcRequest
impl UnitGrpcRequest
Sourcepub fn initial_metadata(&self) -> &Vec<(String, Bytes)>
pub fn initial_metadata(&self) -> &Vec<(String, Bytes)>
Returns a reference to the initial metadata (headers) of the gRPC request.