pub trait Backend {
// Required method
fn call(&self, req: UnitHttpRequest) -> UnitHttpResponse;
}Expand description
The interface for a backend that can be used to mock the response of an http service.
pub trait Backend {
// Required method
fn call(&self, req: UnitHttpRequest) -> UnitHttpResponse;
}The interface for a backend that can be used to mock the response of an http service.