Backend

Trait Backend 

pub trait Backend {
    // Required method
    fn call(&self, req: UnitHttpRequest) -> UnitHttpResponse;
}
The interface for a backend that can be used to mock the response of an http service.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<B: Backend> Backend for Rc<B>

Implementors