pub trait Backend {
// Required method
fn call(&self, req: UnitHttpRequest) -> UnitHttpResponse;
}Expand description
The interface for a backend that can be used to mock the response of an http service.
Required Methods
fn call(&self, req: UnitHttpRequest) -> UnitHttpResponse
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".